<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>sedaj</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nova poročila</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuto pred</translation>
    </message>
</context>
</TS>